package java.awt.image;

import java.awt.Rectangle;
import java.util.Hashtable;

public class CropImageFilter extends ImageFilter
{
    int cropX;
    int cropY;
    int cropW;
    int cropH;
    
    public CropImageFilter(int cropX, int cropY, int cropW, int cropH) {
        this.cropX = cropX;
        this.cropY = cropY;
        this.cropW = cropW;
        this.cropH = cropH;
    }
    
    @Override
    public void setProperties(Hashtable<?, ?> hashtable) {
        Hashtable<String, Rectangle> properties = (Hashtable)hashtable.clone();
        properties.put("croprect", new Rectangle(this.cropX, this.cropY, this.cropW, this.cropH));
        super.setProperties(properties);
    }
    
    @Override
    public void setDimensions(int n, int n2) {
        this.consumer.setDimensions(this.cropW, this.cropH);
    }
    
    @Override
    public void setPixels(int cropX, int cropY, int n, int n2, ColorModel colorModel, byte[] array, int n3, int n4) {
        if (cropX < this.cropX) {
            cropX = this.cropX;
        }
        int addWithoutOverflow = this.addWithoutOverflow(cropX, n);
        if (addWithoutOverflow > this.cropX + this.cropW) {
            addWithoutOverflow = this.cropX + this.cropW;
        }
        if ((cropY = cropY) < this.cropY) {
            cropY = this.cropY;
        }
        int addWithoutOverflow2 = this.addWithoutOverflow(cropY, n2);
        if (addWithoutOverflow2 > this.cropY + this.cropH) {
            addWithoutOverflow2 = this.cropY + this.cropH;
        }
        if (cropX >= addWithoutOverflow || cropY >= addWithoutOverflow2) {
            return;
        }
        this.consumer.setPixels(cropX - this.cropX, cropY - this.cropY, addWithoutOverflow - cropX, addWithoutOverflow2 - cropY, colorModel, array, n3 + (cropY - cropY) * n4 + (cropX - cropX), n4);
        return;
    }
    
    @Override
    public void setPixels(int cropX, int cropY, int n, int n2, ColorModel colorModel, int[] array, int n3, int n4) {
        if (cropX < this.cropX) {
            cropX = this.cropX;
        }
        int addWithoutOverflow = this.addWithoutOverflow(cropX, n);
        if (addWithoutOverflow > this.cropX + this.cropW) {
            addWithoutOverflow = this.cropX + this.cropW;
        }
        if ((cropY = cropY) < this.cropY) {
            cropY = this.cropY;
        }
        int addWithoutOverflow2 = this.addWithoutOverflow(cropY, n2);
        if (addWithoutOverflow2 > this.cropY + this.cropH) {
            addWithoutOverflow2 = this.cropY + this.cropH;
        }
        if (cropX >= addWithoutOverflow || cropY >= addWithoutOverflow2) {
            return;
        }
        this.consumer.setPixels(cropX - this.cropX, cropY - this.cropY, addWithoutOverflow - cropX, addWithoutOverflow2 - cropY, colorModel, array, n3 + (cropY - cropY) * n4 + (cropX - cropX), n4);
        return;
    }
    
    private int addWithoutOverflow(int n, int n2) {
        int n3 = n + n2;
        if (n > 0 && n2 > 0 && n3 < 0) {
            n3 = Integer.MAX_VALUE;
        }
        else if (n < 0 && n2 < 0 && n3 > 0) {
            n3 = Integer.MIN_VALUE;
        }
        return n3;
    }
}
